@@ -375,9 +375,8 @@ ViewOvBoxRealize(GtkWidget *widget) // IN
    attributes.window_type = GDK_WINDOW_CHILD;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
-   attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget) | GDK_EXPOSURE_MASK;
-   mask = GDK_WA_VISUAL | GDK_WA_COLORMAP | GDK_WA_X | GDK_WA_Y;
+   mask = GDK_WA_VISUAL | GDK_WA_X | GDK_WA_Y;
 
    gtk_widget_get_allocation(widget, &allocation);
    attributes.x = allocation.x;
@@ -506,6 +505,30 @@ ViewOvBoxSizeRequest(GtkWidget *widget,           // IN
    requisition->height = MAX(underR.height + min, priv->overR.height);
 }
 
+static void
+ViewOvBox_get_preferred_width (GtkWidget *widget,
+                               gint      *minimal_width,
+                               gint      *natural_width)
+{
+  GtkRequisition requisition;
+
+  ViewOvBoxSizeRequest (widget, &requisition);
+
+  *minimal_width = *natural_width = requisition.width;
+}
+
+static void
+ViewOvBox_get_preferred_height (GtkWidget *widget,
+                                gint      *minimal_height,
+                                gint      *natural_height)
+{
+  GtkRequisition requisition;
+
+  ViewOvBoxSizeRequest (widget, &requisition);
+
+  *minimal_height = *natural_height = requisition.height;
+}
+
 
 /*
  *-----------------------------------------------------------------------------
@@ -686,7 +709,8 @@ ViewOvBoxClassInit(ViewOvBoxClass *klass) // IN
    widgetClass->unmap = ViewOvBoxUnmap;
    widgetClass->realize = ViewOvBoxRealize;
    widgetClass->unrealize = ViewOvBoxUnrealize;
-   widgetClass->size_request = ViewOvBoxSizeRequest;
+   widgetClass->get_preferred_width = ViewOvBox_get_preferred_width;
+   widgetClass->get_preferred_height = ViewOvBox_get_preferred_height;
    widgetClass->size_allocate = ViewOvBoxSizeAllocate;
    widgetClass->style_set = ViewOvBoxStyleSet;
 
